.. epyc documentation master file, created by
   sphinx-quickstart on Wed Sep 21 18:23:06 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

epyc: Computational experiment management in Python
===================================================

.. automodule:: epyc


Core classes and concepts
-------------------------

.. toctree::
   :maxdepth: 2

   experiment
   labnotebook
   lab
   glossary
   
Extended functionality
----------------------

.. toctree::
   :maxdepth: 2

   repeatedexperiment
   summaryexperiment
   jsonlabnotebook
   clusterlab
   
   

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

